==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/sidebar/fragments/SidebarAvailableElements.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/sidebar/fragments/SidebarAvailableElements.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-state', 'frontend-js-metal-web$metal-drag-drop', 'frontend-js-metal-web$metal-position', 'frontend-js-metal-web$metal-soy', './FragmentsEditorSidebarCard.es', '../../../actions/actions.es', '../../../actions/saveChanges.es', '../../../utils/constants', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorDragDrop.es', '../../../utils/FragmentsEditorUpdateUtils.es', './SidebarAvailableElements.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.SidebarAvailableElements = exports.ConnectedSidebarAvailableElements = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _metalDragDrop = require("frontend-js-metal-web$metal-drag-drop");

  var _metalPosition = _interopRequireDefault(require("frontend-js-metal-web$metal-position"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("./FragmentsEditorSidebarCard.es");

  var _actions = require("../../../actions/actions.es");

  var _saveChanges = require("../../../actions/saveChanges.es");

  var _constants = require("../../../utils/constants");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorDragDrop = require("../../../utils/FragmentsEditorDragDrop.es");

  var _FragmentsEditorUpdateUtils = require("../../../utils/FragmentsEditorUpdateUtils.es");

  var _SidebarAvailableElements = _interopRequireDefault(require("./SidebarAvailableElements.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * SidebarAvailableElements
   */
  var SidebarAvailableElements =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SidebarAvailableElements, _Component);

    function SidebarAvailableElements() {
      _classCallCheck(this, SidebarAvailableElements);

      return _possibleConstructorReturn(this, _getPrototypeOf(SidebarAvailableElements).apply(this, arguments));
    }

    _createClass(SidebarAvailableElements, [{
      key: "attached",

      /**
       * @inheritDoc
       * @private
       * @review
       */
      value: function attached() {
        this._initializeDragAndDrop();
      }
      /**
       * @inheritDoc
       * @private
       * @review
       */

    }, {
      key: "disposed",
      value: function disposed() {
        this._dragDrop.dispose();
      }
      /**
       * Handle layoutData changed
       * @inheritDoc
       * @review
       */

    }, {
      key: "syncLayoutData",
      value: function syncLayoutData() {
        this._initializeDragAndDrop();
      }
      /**
       * Callback that is executed when an item is being dragged.
       * @param {object} eventData
       * @param {MouseEvent} eventData.originalEvent
       * @private
       * @review
       */

    }, {
      key: "_handleDrag",
      value: function _handleDrag(eventData) {
        var targetItem = eventData.target;
        var data = targetItem ? targetItem.dataset : null;
        var targetIsColumn = targetItem && 'columnId' in data;
        var targetIsFragment = targetItem && 'fragmentEntryLinkId' in data;
        var targetIsRow = targetItem && 'layoutRowId' in data;
        (0, _FragmentsEditorUpdateUtils.setDraggingItemPosition)(eventData.originalEvent);

        if (targetIsColumn || targetIsFragment || targetIsRow) {
          var mouseY = eventData.originalEvent.clientY;

          var targetItemRegion = _metalPosition.default.getRegion(targetItem);

          var nearestBorder = _constants.FRAGMENTS_EDITOR_ITEM_BORDERS.bottom;

          if (Math.abs(mouseY - targetItemRegion.top) <= Math.abs(mouseY - targetItemRegion.bottom)) {
            nearestBorder = _constants.FRAGMENTS_EDITOR_ITEM_BORDERS.top;
          }

          var dropTargetItemId = null;
          var dropTargetItemType = null;

          if (targetIsColumn) {
            dropTargetItemId = data.columnId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.column;
          } else if (targetIsFragment) {
            dropTargetItemId = data.fragmentEntryLinkId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.fragment;
          } else if (targetIsRow) {
            dropTargetItemId = data.layoutRowId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.row;
          }

          this.store.dispatch({
            dropTargetBorder: nearestBorder,
            dropTargetItemId: dropTargetItemId,
            dropTargetItemType: dropTargetItemType,
            type: _actions.UPDATE_DROP_TARGET
          });
        }
      }
      /**
       * Callback that is executed when we leave a drag target.
       * @private
       * @review
       */

    }, {
      key: "_handleDragEnd",
      value: function _handleDragEnd() {
        this.store.dispatch({
          type: _actions.CLEAR_DROP_TARGET
        });
      }
      /**
       * Callback that is executed when an item is dropped.
       * @param {!object} data
       * @param {!MouseEvent} event
       * @private
       * @review
       */

    }, {
      key: "_handleDrop",
      value: function _handleDrop(data, event) {
        var _this = this;

        event.preventDefault();

        if (data.target) {
          var _data$source$dataset = data.source.dataset,
              itemId = _data$source$dataset.itemId,
              itemName = _data$source$dataset.itemName;
          requestAnimationFrame(function () {
            _this._initializeDragAndDrop();
          });
          this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
            fragmentEntryKey: itemId,
            fragmentName: itemName,
            type: _actions.ADD_FRAGMENT_ENTRY_LINK
          }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)()).dispatch({
            type: _actions.CLEAR_DROP_TARGET
          });
        }
      }
      /**
       * Callback that is executed when a fragment entry is clicked.
       * @param {{
       *   itemId: !string,
       *   itemName: !string
       * }} event
       * @private
       */

    }, {
      key: "_handleEntryClick",
      value: function _handleEntryClick(event) {
        this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
          fragmentEntryKey: event.itemId,
          fragmentName: event.itemName,
          type: _actions.ADD_FRAGMENT_ENTRY_LINK
        }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_initializeDragAndDrop",
      value: function _initializeDragAndDrop() {
        if (this._dragDrop) {
          this._dragDrop.dispose();
        }

        this._dragDrop = (0, _FragmentsEditorDragDrop.initializeDragDrop)({
          handles: '.fragments-editor__drag-handler',
          sources: '.fragments-editor__drag-source--sidebar-fragment',
          targets: '.fragments-editor__drop-target--sidebar-fragment'
        });

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.DRAG, this._handleDrag.bind(this));

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.END, this._handleDrop.bind(this));

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.TARGET_LEAVE, this._handleDragEnd.bind(this));
      }
    }]);

    return SidebarAvailableElements;
  }(_metalComponent.default);
  /**
   * State definition.
   * @type {!Object}
   * @static
   */

  exports.SidebarAvailableElements = SidebarAvailableElements;
  SidebarAvailableElements.STATE = {
    /**
     * Internal DragDrop instance.
     * @default null
     * @instance
     * @memberOf SidebarAvailableElements
     * @review
     * @type {object|null}
     */
    _dragDrop: _metalState.Config.internal().value(null)
  };
  var ConnectedSidebarAvailableElements = (0, _ConnectedComponent.getConnectedComponent)(SidebarAvailableElements, ['layoutData', 'elements', 'spritemap']);
  exports.ConnectedSidebarAvailableElements = ConnectedSidebarAvailableElements;

  _metalSoy.default.register(ConnectedSidebarAvailableElements, _SidebarAvailableElements.default);

  var _default = ConnectedSidebarAvailableElements;
  exports.default = _default;
  //# sourceMappingURL=SidebarAvailableElements.es.js.map
});
//# sourceMappingURL=SidebarAvailableElements.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/sidebar/fragments/SidebarAvailableElements.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/sidebar/fragments/SidebarAvailableElements.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-drag-drop', 'frontend-js-metal-web$metal-position', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FragmentsEditorSidebarCard.es', '../../../actions/actions.es', '../../../actions/saveChanges.es', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorDragDrop.es', '../../../utils/FragmentsEditorUpdateUtils.es', '../../../utils/constants', './SidebarAvailableElements.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.SidebarAvailableElements = exports.ConnectedSidebarAvailableElements = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalDragDrop = require("frontend-js-metal-web$metal-drag-drop");

  var _metalPosition = _interopRequireDefault(require("frontend-js-metal-web$metal-position"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./FragmentsEditorSidebarCard.es");

  var _actions = require("../../../actions/actions.es");

  var _saveChanges = require("../../../actions/saveChanges.es");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorDragDrop = require("../../../utils/FragmentsEditorDragDrop.es");

  var _FragmentsEditorUpdateUtils = require("../../../utils/FragmentsEditorUpdateUtils.es");

  var _constants = require("../../../utils/constants");

  var _SidebarAvailableElements = _interopRequireDefault(require("./SidebarAvailableElements.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * SidebarAvailableElements
   */
  var SidebarAvailableElements =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SidebarAvailableElements, _Component);

    function SidebarAvailableElements() {
      _classCallCheck(this, SidebarAvailableElements);

      return _possibleConstructorReturn(this, _getPrototypeOf(SidebarAvailableElements).apply(this, arguments));
    }

    _createClass(SidebarAvailableElements, [{
      key: "attached",

      /**
       * @inheritDoc
       * @private
       * @review
       */
      value: function attached() {
        this._initializeDragAndDrop();
      }
      /**
       * @inheritDoc
       * @private
       * @review
       */

    }, {
      key: "disposed",
      value: function disposed() {
        this._dragDrop.dispose();
      }
      /**
       * Handle layoutData changed
       * @inheritDoc
       * @review
       */

    }, {
      key: "syncLayoutData",
      value: function syncLayoutData() {
        this._initializeDragAndDrop();
      }
      /**
       * Callback that is executed when an item is being dragged.
       * @param {object} eventData
       * @param {MouseEvent} eventData.originalEvent
       * @private
       * @review
       */

    }, {
      key: "_handleDrag",
      value: function _handleDrag(eventData) {
        var targetItem = eventData.target;
        var data = targetItem ? targetItem.dataset : null;
        var targetIsColumn = targetItem && 'columnId' in data;
        var targetIsFragment = targetItem && 'fragmentEntryLinkId' in data;
        var targetIsRow = targetItem && 'layoutRowId' in data;
        (0, _FragmentsEditorUpdateUtils.setDraggingItemPosition)(eventData.originalEvent);

        if (targetIsColumn || targetIsFragment || targetIsRow) {
          var mouseY = eventData.originalEvent.clientY;

          var targetItemRegion = _metalPosition["default"].getRegion(targetItem);

          var nearestBorder = _constants.FRAGMENTS_EDITOR_ITEM_BORDERS.bottom;

          if (Math.abs(mouseY - targetItemRegion.top) <= Math.abs(mouseY - targetItemRegion.bottom)) {
            nearestBorder = _constants.FRAGMENTS_EDITOR_ITEM_BORDERS.top;
          }

          var dropTargetItemId = null;
          var dropTargetItemType = null;

          if (targetIsColumn) {
            dropTargetItemId = data.columnId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.column;
          } else if (targetIsFragment) {
            dropTargetItemId = data.fragmentEntryLinkId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.fragment;
          } else if (targetIsRow) {
            dropTargetItemId = data.layoutRowId;
            dropTargetItemType = _constants.FRAGMENTS_EDITOR_ITEM_TYPES.row;
          }

          this.store.dispatch({
            dropTargetBorder: nearestBorder,
            dropTargetItemId: dropTargetItemId,
            dropTargetItemType: dropTargetItemType,
            type: _actions.UPDATE_DROP_TARGET
          });
        }
      }
      /**
       * Callback that is executed when we leave a drag target.
       * @private
       * @review
       */

    }, {
      key: "_handleDragEnd",
      value: function _handleDragEnd() {
        this.store.dispatch({
          type: _actions.CLEAR_DROP_TARGET
        });
      }
      /**
       * Callback that is executed when an item is dropped.
       * @param {!object} data
       * @param {!MouseEvent} event
       * @private
       * @review
       */

    }, {
      key: "_handleDrop",
      value: function _handleDrop(data, event) {
        var _this = this;

        event.preventDefault();

        if (data.target) {
          var _data$source$dataset = data.source.dataset,
              itemGroupId = _data$source$dataset.itemGroupId,
              itemId = _data$source$dataset.itemId,
              itemName = _data$source$dataset.itemName;
          requestAnimationFrame(function () {
            _this._initializeDragAndDrop();
          });
          this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
            fragmentEntryKey: itemId,
            fragmentName: itemName,
            groupId: itemGroupId,
            type: _actions.ADD_FRAGMENT_ENTRY_LINK
          }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)()).dispatch({
            type: _actions.CLEAR_DROP_TARGET
          });
        }
      }
      /**
       * Callback that is executed when a fragment entry is clicked.
       * @param {{
       *   itemId: !string,
       *   itemName: !string
       * }} event
       * @private
       */

    }, {
      key: "_handleEntryClick",
      value: function _handleEntryClick(event) {
        this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
          fragmentEntryKey: event.itemId,
          fragmentName: event.itemName,
          groupId: event.itemGroupId,
          type: _actions.ADD_FRAGMENT_ENTRY_LINK
        }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_initializeDragAndDrop",
      value: function _initializeDragAndDrop() {
        if (this._dragDrop) {
          this._dragDrop.dispose();
        }

        this._dragDrop = (0, _FragmentsEditorDragDrop.initializeDragDrop)({
          handles: '.fragments-editor__drag-handler',
          sources: '.fragments-editor__drag-source--sidebar-fragment',
          targets: '.fragments-editor__drop-target--sidebar-fragment'
        });

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.DRAG, this._handleDrag.bind(this));

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.END, this._handleDrop.bind(this));

        this._dragDrop.on(_metalDragDrop.DragDrop.Events.TARGET_LEAVE, this._handleDragEnd.bind(this));
      }
    }]);

    return SidebarAvailableElements;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @type {!Object}
   * @static
   */

  exports.SidebarAvailableElements = SidebarAvailableElements;
  SidebarAvailableElements.STATE = {
    /**
     * Internal DragDrop instance.
     * @default null
     * @instance
     * @memberOf SidebarAvailableElements
     * @review
     * @type {object|null}
     */
    _dragDrop: _metalState.Config.internal().value(null)
  };
  var ConnectedSidebarAvailableElements = (0, _ConnectedComponent.getConnectedComponent)(SidebarAvailableElements, ['layoutData', 'elements', 'spritemap']);
  exports.ConnectedSidebarAvailableElements = ConnectedSidebarAvailableElements;

  _metalSoy["default"].register(ConnectedSidebarAvailableElements, _SidebarAvailableElements["default"]);

  var _default = ConnectedSidebarAvailableElements;
  exports["default"] = _default;
  //# sourceMappingURL=SidebarAvailableElements.es.js.map
});
//# sourceMappingURL=SidebarAvailableElements.es.js.map
